##  Create a New API Role
  1. Go to Administration → Role Management → Add Administrator Role.
  2. Provide a suitable name. Since the API role does not require full permissions, you can limit the access as follows:
Settings | Permission
---|---
Logs Limit (Days) | Unrestricted
Reporting Access | None
Alert Access | None
Device Information | Obfuscated
Dashboard Access | View Only
Insight Access | None
User Names | Obfuscated


  3. Below, under Policy & Components, select the Access Control tab.
  4. Set the URL & Cloud App Control permission to View Only. All other permissions can be set to None.
  5. On the Reporting Data tab, set the Web Data permission to View Only.
  6. Click Save.
